==========
EGADS API
==========

Core Classes
************

.. automodule:: egads.core.egads_core
	:members:
	:show-inheritance:

	
Metadata Classes
*****************

.. automodule:: egads.core.metadata
	:members:
	:show-inheritance:

	
File Classes
*************

.. automodule:: egads.input.input_core
	:members:
	:show-inheritance:

.. automodule:: egads.input.nasa_ames_io
	:members:
	:show-inheritance:

.. automodule:: egads.input.netcdf_io
	:members:
	:show-inheritance:

.. automodule:: egads.input.text_file_io
	:members:
	:show-inheritance:
